## 可转债行情

接口：cb_daily

描述：获取可转债行情

限量：单次最大2000条，可多次提取，总量不限制

积分：用户需要至少2000积分才可以调取，5000积分以上频次相对较高，积分越多权限越大，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| trade_date | str | N | 交易日期(YYYYMMDD格式，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 转债代码 |
| trade_date | str | Y | 交易日期 |
| pre_close | float | Y | 昨收盘价(元) |
| open | float | Y | 开盘价(元) |
| high | float | Y | 最高价(元) |
| low | float | Y | 最低价(元) |
| close | float | Y | 收盘价(元) |
| change | float | Y | 涨跌(元) |
| pct_chg | float | Y | 涨跌幅(%) |
| vol | float | Y | 成交量(手) |
| amount | float | Y | 成交金额(万元) |
| bond_value | float | N | 纯债价值 |
| bond_over_rate | float | N | 纯债溢价率(%) |
| cb_value | float | N | 转股价值 |
| cb_over_rate | float | N | 转股溢价率(%) |

接口示例

```python
pro = ts.pro_api()


#获取可转债行情
df = pro.cb_daily(trade_date='20190719', fields='ts_code,trade_date, pre_close,open,high,low,close')
```

数据示例

```python
ts_code trade_date  pre_close     open     high      low    close  \
0    110030.SH   20190719    104.700  104.710  104.960  104.540  104.660   
```